@@ -1,6 +1,6 @@
 /*
  * Copyright (c) [2011-2015] Novell, Inc.
- * Copyright (c) 2016 SUSE LLC
+ * Copyright (c) [2016-2023] SUSE LLC
  *
  * All Rights Reserved.
  *
@@ -25,12 +25,12 @@
 #define SNAPPER_SNAPPER_H
 
 
-#include <iterator>
 #include <vector>
 #include <boost/noncopyable.hpp>
 
 #include "snapper/Snapshot.h"
 #include "snapper/AsciiFile.h"
+#include "snapper/Plugins.h"
 
 
 namespace snapper
@@ -49,10 +49,10 @@ namespace snapper
 
 	explicit ConfigInfo(const string& config_name, const string& root_prefix);
 
-	const string& getConfigName() const { return config_name; }
-	const string& getSubvolume() const { return subvolume; }
+	const string& get_config_name() const { return config_name; }
+	const string& get_subvolume() const { return subvolume; }
 
-	virtual void checkKey(const string& key) const override;
+	virtual void check_key(const string& key) const override;
 
     private:
 
@@ -129,7 +129,7 @@ namespace snapper
 	Snapper(const string& config_name, const string& root_prefix, bool disable_filters = false);
 	~Snapper();
 
-	const string& configName() const { return config_info->getConfigName(); }
+	const string& configName() const { return config_info->get_config_name(); }
 
 	string subvolumeDir() const;
 
@@ -141,15 +141,27 @@ namespace snapper
 
 	Snapshots::const_iterator getSnapshotCurrent() const;
 
-	Snapshots::iterator createSingleSnapshot(const SCD& scd);
-	Snapshots::iterator createSingleSnapshot(Snapshots::const_iterator parent, const SCD& scd);
-	Snapshots::iterator createSingleSnapshotOfDefault(const SCD& scd);
-	Snapshots::iterator createPreSnapshot(const SCD& scd);
-	Snapshots::iterator createPostSnapshot(Snapshots::const_iterator pre, const SCD& scd);
+	Snapshots::iterator createSingleSnapshot(const SCD& scd) SN_DEPRECATED;
+	Snapshots::iterator createSingleSnapshot(Snapshots::const_iterator parent, const SCD& scd) SN_DEPRECATED;
+	Snapshots::iterator createSingleSnapshotOfDefault(const SCD& scd) SN_DEPRECATED;
+	Snapshots::iterator createPreSnapshot(const SCD& scd) SN_DEPRECATED;
+	Snapshots::iterator createPostSnapshot(Snapshots::const_iterator pre, const SCD& scd) SN_DEPRECATED;
 
-	void modifySnapshot(Snapshots::iterator snapshot, const SMD& smd);
+	void modifySnapshot(Snapshots::iterator snapshot, const SMD& smd) SN_DEPRECATED;
 
-	void deleteSnapshot(Snapshots::iterator snapshot);
+	void deleteSnapshot(Snapshots::iterator snapshot) SN_DEPRECATED;
+
+	Snapshots::iterator createSingleSnapshot(const SCD& scd, Plugins::Report& report);
+	Snapshots::iterator createSingleSnapshot(Snapshots::const_iterator parent, const SCD& scd,
+						 Plugins::Report& report);
+	Snapshots::iterator createSingleSnapshotOfDefault(const SCD& scd, Plugins::Report& report);
+	Snapshots::iterator createPreSnapshot(const SCD& scd, Plugins::Report& report);
+	Snapshots::iterator createPostSnapshot(Snapshots::const_iterator pre, const SCD& scd,
+					       Plugins::Report& report);
+
+	void modifySnapshot(Snapshots::iterator snapshot, const SMD& smd, Plugins::Report& report);
+
+	void deleteSnapshot(Snapshots::iterator snapshot, Plugins::Report& report);
 
 	const vector<string>& getIgnorePatterns() const { return ignore_patterns; }
 
@@ -158,8 +170,13 @@ namespace snapper
 
 	static void createConfig(const string& config_name, const string& root_prefix,
 				 const string& subvolume, const string& fstype,
-				 const string& template_name);
-	static void deleteConfig(const string& config_name, const string& root_prefix);
+				 const string& template_name) SN_DEPRECATED;
+	static void deleteConfig(const string& config_name, const string& root_prefix) SN_DEPRECATED;
+
+	static void createConfig(const string& config_name, const string& root_prefix,
+				 const string& subvolume, const string& fstype,
+				 const string& template_name, Plugins::Report& report);
+	static void deleteConfig(const string& config_name, const string& root_prefix, Plugins::Report& report);
 
 	static bool detectFstype(const string& subvolume, string& fstype);
 
@@ -187,6 +204,12 @@ namespace snapper
 	 */
 	void calculateUsedSpace() const;
 
+	/**
+	 * Return the compression algorithm set in the config file or a fallback. Also
+	 * checks if the compression is available and uses NONE as a fallback.
+	 */
+	Compression get_compression() const;
+
 	static const char* compileVersion();
 	static const char* compileFlags();
 
@@ -201,20 +224,21 @@ namespace snapper
 
 	void syncAcl(const vector<uid_t>& uids, const vector<gid_t>& gids) const;
 
-	void syncSelinuxContexts(bool skip_snapshot_dir) const;
-	void syncSelinuxContextsInInfosDir(bool skip_snapshot_dir) const;
+	void syncSelinuxContexts(SelinuxLabelHandle* selabel_handle, bool skip_snapshot_dir) const;
+	void syncSelinuxContextsInInfosDir(SelinuxLabelHandle* selabel_handle, bool skip_snapshot_dir) const;
+
 	void syncInfoDir(SDir& dir) const;
 
-	ConfigInfo* config_info;
+	// const std::string root_prefix; // TODO ABI change
 
-	Filesystem* filesystem;
+	ConfigInfo* config_info = nullptr;
+
+	Filesystem* filesystem = nullptr;
 
 	vector<string> ignore_patterns;
 
 	Snapshots snapshots;
 
-	SelinuxLabelHandle* selabel_handle;
-
     };
 
 }
